about summary refs log tree commit diff
diff options
context:
space:
mode:
authorHuon Wilson <dbau.pp+github@gmail.com>2013-06-14 00:35:06 +1000
committerHuon Wilson <dbau.pp+github@gmail.com>2013-06-14 11:12:06 +1000
commite6c3e4a000557580e75464f843714bd34ae00c99 (patch)
tree0001053b5e2c5e564b8971042598947a4b635c2d
parentf93a974558bf09bee475427158150ba6e008cdd8 (diff)
downloadrust-e6c3e4a000557580e75464f843714bd34ae00c99.tar.gz
rust-e6c3e4a000557580e75464f843714bd34ae00c99.zip
syntax: revert the uint -> u32 "fix"; make the names/comment match.
-rw-r--r--src/libsyntax/ext/deriving/rand.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/libsyntax/ext/deriving/rand.rs b/src/libsyntax/ext/deriving/rand.rs
index 79aa3469f74..b890623b963 100644
--- a/src/libsyntax/ext/deriving/rand.rs
+++ b/src/libsyntax/ext/deriving/rand.rs
@@ -78,13 +78,13 @@ fn rand_substructure(cx: @ExtCtxt, span: span, substr: &Substructure) -> @expr {
 
             let variant_count = cx.expr_uint(span, variants.len());
 
-            // need to specify the u32-ness of the random number
-            let u32_ty = cx.ty_ident(span, cx.ident_of("u32"));
+            // need to specify the uint-ness of the random number
+            let uint_ty = cx.ty_ident(span, cx.ident_of("uint"));
             let r_ty = cx.ty_ident(span, cx.ident_of("R"));
-            let rand_name = cx.path_all(span, true, copy rand_ident, None, ~[ u32_ty, r_ty ]);
+            let rand_name = cx.path_all(span, true, copy rand_ident, None, ~[ uint_ty, r_ty ]);
             let rand_name = cx.expr_path(rand_name);
 
-            // ::std::rand::Rand::rand::<u32>(rng)
+            // ::std::rand::Rand::rand::<uint>(rng)
             let rv_call = cx.expr_call(span,
                                        rand_name,
                                        ~[ rng[0].duplicate(cx) ]);